/*
  * JBoss, Home of Professional Open Source
  * Copyright 2005, JBoss Inc., and individual contributors as indicated
  * by the @authors tag. See the copyright.txt in the distribution for a
  * full listing of individual contributors.
  *
  * This is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as
  * published by the Free Software Foundation; either version 2.1 of
  * the License, or (at your option) any later version.
  *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this software; if not, write to the Free
  * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
  * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
  */
package org.jboss.messaging.core;

import java.io.Serializable;


/**
 * A filter encapsulates the logic of whether to accept a message or not. Filters are used when
 * browsing to restrict the messages browsed, or when routing messages.
 *
 * A filter must be serializable because it can be sent between two address spaces as argument
 * of a distributed RPC.
 *
 * @author <a href="mailto:tim.fox@jboss.com">Tim Fox</a>
 * @author <a href="mailto:ovidiu@jboss.org">Ovidiu Feodorov</a>
 * @version <tt>$Revision: 886 $</tt>
 *
 * $Id: Filter.java 886 2006-04-13 08:57:49Z timfox $
 */
public interface Filter extends Serializable
{
	/**
	 * Tests whether the routable should be accepted.
    *
	 * @return true if the Filter accepts the routable - i.e. let's it pass.
	 */
	boolean accept(Routable routable);
}
