/**
 * JBoss, Home of Professional Open Source
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package org.jboss.test.thirdparty.remoting.util;

import org.jboss.remoting.ServerInvocationHandler;
import org.jboss.remoting.ServerInvoker;
import org.jboss.remoting.InvocationRequest;
import org.jboss.remoting.callback.InvokerCallbackHandler;
import org.jboss.logging.Logger;

import javax.management.MBeanServer;
import java.io.Serializable;
import java.util.List;
import java.util.ArrayList;

import EDU.oswego.cs.dl.util.concurrent.LinkedQueue;
import EDU.oswego.cs.dl.util.concurrent.Channel;

/**
 * @author <a href="mailto:ovidiu@jboss.org">Ovidiu Feodorov</a>
 * @version <tt>$Revision: 2098 $</tt>
 *
 * $Id: RemotingTestSubsystem.java 2098 2007-01-30 07:21:00Z ovidiu.feodorov@jboss.com $
 */
public class RemotingTestSubsystem
   implements TestableSubsystem, ServerInvocationHandler, Serializable
{
   // Constants ------------------------------------------------------------------------------------

   private static final long serialVersionUID = 5457454557215715L;

   private static final Logger log = Logger.getLogger(RemotingTestSubsystem.class);

   // Static ---------------------------------------------------------------------------------------

   /**
    * Very quick and dirty method. Don't try it at home. Needed it because some InvocationRequests
    * (even if the class is declared Serializable) contain request and response payloads which are
    * not, so I am having trouble sending them over wire back to the client.
    */
   private static InvocationRequest dirtyCopy(InvocationRequest source)
   {
      return new InvocationRequest(source.getSessionId(),
                                   source.getSubsystem(),
                                   source.getParameter(),
                                   null,
                                   null,
                                   source.getLocator());
   }

   // Attributes -----------------------------------------------------------------------------------

   private Channel invocationHistory;
   private List callbackListeners;

   private boolean failed;

   // Constructors ---------------------------------------------------------------------------------

   public RemotingTestSubsystem()
   {
      invocationHistory = new LinkedQueue();
      callbackListeners = new ArrayList();
      failed = false;
   }

   // ServerInvocationHandler implementation -------------------------------------------------------

   public void setMBeanServer(MBeanServer server)
   {
   }

   public void setInvoker(ServerInvoker invoker)
   {
   }

   public Object invoke(InvocationRequest invocation) throws Throwable
   {
      log.debug(this + " received " + invocation);

      final Object parameter = invocation.getParameter();

      if ("ignore".equals(parameter))
      {
         // used in stress tests, do not accumulate record the invocation in history, since the
         // client is goint to send a lot of them ....
         log.debug(this + " ignoring invocation");
         return null;
      }

      invocationHistory.put(dirtyCopy(invocation));

      return null;
   }

   public void addListener(InvokerCallbackHandler callbackHandler)
   {
      synchronized(callbackListeners)
      {
         callbackListeners.add(callbackHandler);
      }
   }

   public void removeListener(InvokerCallbackHandler callbackHandler)
   {
      synchronized(callbackListeners)
      {
         callbackListeners.remove(callbackHandler);
      }
   }

   // TestableSubsystem implementation ----------------------------------------------------------

   public InvocationRequest getNextInvocation(long timeout) throws InterruptedException
   {
      return (InvocationRequest)invocationHistory.poll(timeout);
   }

   public boolean isFailed()
   {
      synchronized (this)
      {
         return failed;
      }
   }

   // Public ---------------------------------------------------------------------------------------

   public String toString()
   {
      return "RemotingTestSubsystem[" + Integer.toHexString(hashCode()) + "]";
   }

   // Package protected ----------------------------------------------------------------------------

   // Protected ------------------------------------------------------------------------------------

   // Private --------------------------------------------------------------------------------------

   // Inner classes --------------------------------------------------------------------------------
}
